@@ -315,15 +315,6 @@ class GitLabFormCore(object):
         if approvers is not None or approver_groups is not None \
                 and approvals and 'approvals_before_merge' in approvals:
 
-            # because of https://gitlab.com/gitlab-org/gitlab/issues/198770 we cannot set more than 1 user
-            # or 1 group as approvers, sorry
-            if (approvers and len(approvers) > 1) or (approver_groups and len(approver_groups) > 1):
-                logging.fatal("Because of https://gitlab.com/gitlab-org/gitlab/issues/198770 you cannot set more than "
-                              "1 user or 1 group as approvers, sorry."
-                              "Please see https://github.com/egnyte/gitlabform/issues/68#issuecomment-581003703 "
-                              "for information about a possible workaround for this limitation.")
-                sys.exit(4)
-
             # in pre-12.3 API approvers (users and groups) were configured under the same endpoint as approvals settings
             approvals_settings = self.gl.get_approvals_settings(project_and_group)
             if 'approvers' in approvals_settings or 'approver_groups' in approvals_settings:
@@ -486,16 +477,16 @@ class GitLabFormCore(object):
                         expires_at_before = users_before_by_username[user]['expires_at']
 
                         if access_level_before == access_level_to_set and expires_at_before == expires_at_to_set:
-                            logging.debug("Nothing to change for user '%s' - same config now as to set.")
+                            logging.debug("Nothing to change for user '%s' - same config now as to set.", user)
                         else:
-                            logging.debug("Re-adding user '%s' to change their access level or expires at.")
+                            logging.debug("Re-adding user '%s' to change their access level or expires at.", user)
                             # we will remove the user first and then re-add they,
                             # to ensure that the user has the expected access level
                             self.gl.remove_member_from_group(group, user)
                             self.gl.add_member_to_group(group, user, access_level_to_set, expires_at_to_set)
 
                     else:
-                        logging.debug("Adding user '%s' who previously was not a member.")
+                        logging.debug("Adding user '%s' who previously was not a member.", user)
                         self.gl.add_member_to_group(group, user, access_level_to_set, expires_at_to_set)
 
             if configuration.get('enforce_group_members'):
@@ -503,7 +494,7 @@ class GitLabFormCore(object):
                 # note: only direct members are removed - inherited are left
                 users_not_configured = set([user['username'] for user in users_before]) - set(users_to_set_by_username.keys())
                 for user in users_not_configured:
-                    logging.debug("Removing user '%s' who is not configured to be a member.")
+                    logging.debug("Removing user '%s' who is not configured to be a member.", user)
                     self.gl.remove_member_from_group(group, user)
             else:
                 logging.debug("Not enforcing group members.")
@@ -566,17 +557,12 @@ class GitLabFormCore(object):
                 logging.debug("Deleting service '%s'", service)
                 self.gl.delete_service(project_and_group, service)
             else:
-
-                if configuration.get('services|' + service + '|recreate'):
-                    try:
-                        # try to workaround issues like https://github.com/egnyte/gitlabform/issues/69 :
-                        # if service change does not work, then try to recreate it each time
-                        self.gl.get_service(project_and_group, service)
-                        logging.debug("Deleting service '%s' first as a workaround for GitLab issues", service)
-                        self.gl.delete_service(project_and_group, service)
-                    except NotFoundException:
-                        logging.debug("Service '%s' is not configured yet.", service)
-
+                if 'recreate' in configuration['services'][service] and configuration['services'][service]['recreate']:
+                    # support from this configuration key has been added in v1.13.4
+                    # we will remove it here to avoid passing it to the GitLab API
+                    logging.warning("Ignoring deprecated 'recreate' field in the '%s' service config. "
+                                    "Please remove it from the config file permanently as this workaround is not "
+                                    "needed anymore.", service)
                     del configuration['services'][service]['recreate']
 
                 logging.debug("Setting service '%s'", service)
